@@ -1,16 +1,13 @@
 package IPC::System::Locale;
 
-our $DATE = '2015-01-04'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-02-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use IPC::System::Options ();
-
-use Exporter qw(import);
-our @EXPORT_OK = qw(system backtick);
+use IPC::System::Options qw(import);
 
 sub system {
     my $opts = ref($_[0]) eq 'HASH' ? shift : {};
@@ -45,7 +42,7 @@ IPC::System::Locale - Set language before executing system() or backtick/qx
 
 =head1 VERSION
 
-This document describes version 0.02 of IPC::System::Locale (from Perl distribution IPC-System-Locale), released on 2015-01-04.
+This document describes version 0.03 of IPC::System::Locale (from Perl distribution IPC-System-Locale), released on 2015-02-07.
 
 =head1 SYNOPSIS
 
@@ -60,6 +57,10 @@ This document describes version 0.02 of IPC::System::Locale (from Perl distribut
  # same for backtick (qx)
  my $output = backtick("df");
 
+Set default options for all calls (prefix each option with dash):
+
+ use IPC::System::Locale 'system', 'backtick', -lang=>'id_ID';
+
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
@@ -80,6 +81,10 @@ This is a shortcut for C<<IPC::System::Options::backtick({lang=>"C"}, ...)>>
 This routine might be helpful if you are checking the output of some program and
 want to make sure that the output is in English/C locale.
 
+=head1 SEE ALSO
+
+L<IPC::System::Options>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/IPC-System-Locale>.
